aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorLior David <qca_liord@qca.qualcomm.com>2016-09-06 16:16:42 +0300
committerHamad Kadmany <hkadmany@codeaurora.org>2016-09-07 15:14:29 +0300
commitb4db19b06bbdbcbc17462d8f6cca85b462996a6e (patch)
tree824ea8acfc1b6cf0c6b239b85e3e6ade1e675a1f
parent9255584daf576795d447cf782d896727bd209412 (diff)
downloadandroid_external_wpa_supplicant_8-b4db19b06bbdbcbc17462d8f6cca85b462996a6e.tar.gz
android_external_wpa_supplicant_8-b4db19b06bbdbcbc17462d8f6cca85b462996a6e.tar.bz2
android_external_wpa_supplicant_8-b4db19b06bbdbcbc17462d8f6cca85b462996a6e.zip
Fix mistakes in definition of QCA vendor commands for indoor location
Fix some mistakes in the previous commit for adding QCA vendor commands for indoor location. Note: The renamed enum value does not change the ABI, but the addition of QCA_WLAN_VENDOR_ATTR_FTM_MEAS_INVALID in the beginning of enum qca_wlan_vendor_attr_ftm_meas does renumber QCA_WLAN_VENDOR_ATTR_FTM_MEAS_* values. The previous values were committed yesterday and have not been used in any released code yet, so this is a justifiable quick fix. Change-Id: I6aae38db9a719784365e7a18a64d643f89a62a1b Signed-off-by: Lior David <qca_liord@qca.qualcomm.com> Git-commit: a62dea4156910d85ebe42767f68eb2bc97d43245 Git-repo: git://w1.fi/srv/git/hostap.git CRs-Fixed: 1064000
-rw-r--r--src/common/qca-vendor.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/common/qca-vendor.h b/src/common/qca-vendor.h
index e52b0b52..453890b9 100644
--- a/src/common/qca-vendor.h
+++ b/src/common/qca-vendor.h
@@ -1017,7 +1017,7 @@ enum qca_wlan_vendor_attr_loc_capa_flags {
* @QCA_WLAN_VENDOR_ATTR_FTM_PEER_MAC_ADDR: The MAC address of the peer.
* @QCA_WLAN_VENDOR_ATTR_FTM_PEER_MEAS_FLAGS: Various flags related
* to measurement. See enum qca_wlan_vendor_attr_ftm_peer_meas_flags.
* @QCA_WLAN_VENDOR_ATTR_FTM_PEER_MEAS_PARAM: Nested attribute of
* FTM measurement parameters, as specified by IEEE P802.11-REVmc/D7.0
* 9.4.2.167. See enum qca_wlan_vendor_attr_ftm_meas_param for
* list of supported attributes.
@@ -1031,7 +1031,7 @@ enum qca_wlan_vendor_attr_ftm_peer_info {
QCA_WLAN_VENDOR_ATTR_FTM_PEER_INVALID,
QCA_WLAN_VENDOR_ATTR_FTM_PEER_MAC_ADDR,
QCA_WLAN_VENDOR_ATTR_FTM_PEER_MEAS_FLAGS,
- QCA_WLAN_VENDOR_ATTR_FTM_PEER_MEAS_PARAM,
+ QCA_WLAN_VENDOR_ATTR_FTM_PEER_MEAS_PARAMS,
QCA_WLAN_VENDOR_ATTR_FTM_PEER_SECURE_TOKEN_ID,
QCA_WLAN_VENDOR_ATTR_FTM_PEER_AOA_BURST_PERIOD,
/* keep last */
@@ -1224,6 +1224,7 @@ enum qca_vendor_attr_loc_session_status {
* @QCA_WLAN_VENDOR_ATTR_FTM_MEAS_PAD: Dummy attribute for padding.
*/
enum qca_wlan_vendor_attr_ftm_meas {
+ QCA_WLAN_VENDOR_ATTR_FTM_MEAS_INVALID,
QCA_WLAN_VENDOR_ATTR_FTM_MEAS_T1,
QCA_WLAN_VENDOR_ATTR_FTM_MEAS_T2,
QCA_WLAN_VENDOR_ATTR_FTM_MEAS_T3,
@@ -1017,7 +1017,7 @@ enum qca_wlan_vendor_attr_loc_capa_flags {
* @QCA_WLAN_VENDOR_ATTR_FTM_PEER_MEAS_FLAGS: Various flags related
* to measurement. See enum qca_wlan_vendor_attr_ftm_peer_meas_flags.
- * @QCA_WLAN_VENDOR_ATTR_FTM_PEER_MEAS_PARAM: Nested attribute of
+ * @QCA_WLAN_VENDOR_ATTR_FTM_PEER_MEAS_PARAMS: Nested attribute of
* FTM measurement parameters, as specified by IEEE P802.11-REVmc/D7.0
* 9.4.2.167. See enum qca_wlan_vendor_attr_ftm_meas_param for